import os
import time
from moviepy.editor import VideoFileClip


def save_audio_video_file(video_clip: VideoFileClip, output_dir='final_output', filename=None):
    """
    Utility Function to Save an Audio-Video File
    :param video_clip: File-Name of Video Clip
    :param output_dir: Output directory in which Audio File to Add
    :param filename: Complete Path of File-Name to write to
    :return: Complete Path of File-Name written to
    """
    if not filename:
        if not os.path.exists(output_dir):
            os.makedirs(output_dir)
        time_string = time.strftime("%Y%m%d_%H%M%S") + '.mp4'
        write_file_path = os.path.join(output_dir, time_string)
    else:
        write_file_path = filename
    video_clip.write_videofile(write_file_path)
    return write_file_path



import cv2
from moviepy.editor import AudioFileClip, VideoFileClip, concatenate_videoclips


def starting_point_in_time(video_file_name: str, frame_number: int):
    """
    Get starting point in time from Frame Number in a Video File
    :param video_file_name: File-Name of Video
    :param frame_number: Frame Number (less than total number of frames of video)
    :return: Tuple of (Starting Time (in s) and Video's frame-per-second speed
    """
    video = cv2.VideoCapture(video_file_name)
    video_fps = video.get(cv2.CAP_PROP_FPS)
    start_time = frame_number / video_fps
    return start_time, video_fps


def merge_audio_video(audio_file: str, video_file: str, frame_number: int = 0, volume_factor=1):
    """
    Function to merge Audio File into Video File

    :param audio_file: File-Name of Audio
    :param video_file: File-Name of Video
    :param frame_number: Frame Number at which audio file to add in Video File
    :param volume_factor: Factor by which Volume of Audio has to be modified
    :return: Video Clip (with Audio merged) of type moviepy.video.VideoClip
    """
    audio_clip = AudioFileClip(audio_file)
    video_clip = VideoFileClip(video_file)

    start_time, video_fps = starting_point_in_time(video_file, frame_number)

    orig_video_duration = video_clip.duration
    orig_audio_duration = audio_clip.duration

    audio_clip = audio_clip.subclip(0, min(orig_video_duration - start_time, orig_audio_duration))
    audio_clip = audio_clip.volumex(volume_factor)

    first_part = video_clip.subclip(0, start_time)
    second_part = video_clip.subclip(start_time, orig_video_duration)

    second_part.audio = audio_clip

    final_video_clip = concatenate_videoclips([first_part, second_part])
    return final_video_clip


if __name__ == '__main__':
    output_video = merge_audio_video('audio_file_name.mp3', 'video_file_name.mp4')



import os
from moviepy.editor import VideoFileClip


def convert_video_to_audio(video_file: str, start_time: int = 0, video_duration=None):
    """
    Convert A Video File to mp3 format
    :param video_file: File Name of Video
    :param start_time: Starting Time (in s) at which clipping has to do
    :param video_duration: Duration wanted for audio clip
    :return: File-Name of Audio File created
    """
    clip = VideoFileClip(video_file)
    if not video_duration:
        video_duration = clip.duration
    clip = clip.subclip(start_time, start_time + video_duration)
    pre, ext = os.path.splitext(video_file)
    audio_file = pre + '.mp3'
    clip.audio.write_audiofile(audio_file)
    return audio_file


if __name__ == '__main__':
    audio_file_name = convert_video_to_audio('audio_file_in_video_format.mp4')



from .convert_video_to_audio import convert_video_to_audio
from .merge_audio_video import merge_audio_video
from .save_audio_video_file import save_audio_video_file

__name__ = 'av_helper'
__version__ = '1.0.4'
__author__ = 'Vibhu Agarwal'



import setuptools
import av_helper

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('requirements.txt') as f:
    requirements = f.readlines()

setuptools.setup(
    name=av_helper.__name__,
    version=av_helper.__version__,
    author=av_helper.__author__,
    author_email="vibhu4agarwal@gmail.com",
    description="An Audio-Video Helper Utility Package in Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Vibhu-Agarwal/av_helper",
    packages=setuptools.find_packages(),
    license='GPLv3+',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    keywords='audio video av moviepy',
    install_requires=requirements
)
